@@ -49,7 +49,7 @@ package_file <- function(..., path = ".") {
     path <- dirname(path)
 
     if (is_root(path)) {
-      stop("Could not find package root.", call. = FALSE)
+      stop("Could not find package root, is your working directory inside a package?", call. = FALSE)
     }
   }
 
